==> jc-1.4.0.tar.gz: soot/options/CGOptions.h <==
// public class soot.options.CGOptions

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 788d78022c32bf6e soot_options_CGOptions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_options_CGOptions_H_
#define _JC_soot_options_CGOptions_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_soot_options_CGOptions$sub_refs	_jc_soot_options_CGOptions$sub_refs;
typedef struct _jc_soot_options_CGOptions$sub_nonrefs	_jc_soot_options_CGOptions$sub_nonrefs;
typedef struct _jc_soot_options_CGOptions$refs	_jc_soot_options_CGOptions$refs;
typedef struct _jc_soot_options_CGOptions$nonrefs	_jc_soot_options_CGOptions$nonrefs;
typedef struct _jc_soot_options_CGOptions$object	_jc_soot_options_CGOptions$object;

typedef struct _jc_soot_options_CGOptions$fields_struct	_jc_soot_options_CGOptions$fields_struct;
typedef const struct _jc_soot_options_CGOptions$vmethods	_jc_soot_options_CGOptions$vmethods;
typedef const struct _jc_soot_options_CGOptions$vtable	_jc_soot_options_CGOptions$vtable;
typedef const struct _jc_soot_options_CGOptions$vtype	_jc_soot_options_CGOptions$vtype;

// Class fields structure
struct _jc_soot_options_CGOptions$fields_struct {
	jint	context__5f1cfa;
	jint	context__5finsens;
	jint	context__5fobjsens;
};
extern _jc_soot_options_CGOptions$fields_struct _jc_soot_options_CGOptions$class_fields;

// Constructors
extern void _jc_soot_options_CGOptions$method$_init$39bc1e191d75104e(_jc_env *, struct _jc_soot_options_CGOptions$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_soot_options_CGOptions$method$all__5freachable$76af725e0b60b1e8(_jc_env *, struct _jc_soot_options_CGOptions$object *);
extern jint _jc_soot_options_CGOptions$method$context$b9f104a3d74cd388(_jc_env *, struct _jc_soot_options_CGOptions$object *);
extern jboolean _jc_soot_options_CGOptions$method$enabled$e29aaa88d18be18b(_jc_env *, struct _jc_soot_options_CGOptions$object *);
extern jboolean _jc_soot_options_CGOptions$method$safe__5fforname$2fffd7f4e2de688e(_jc_env *, struct _jc_soot_options_CGOptions$object *);
extern jboolean _jc_soot_options_CGOptions$method$safe__5fnewinstance$18b0fbec20bbaa49(_jc_env *, struct _jc_soot_options_CGOptions$object *);
extern jboolean _jc_soot_options_CGOptions$method$trim__5fclinit$5a845e4a8bc0b3d8(_jc_env *, struct _jc_soot_options_CGOptions$object *);
extern jboolean _jc_soot_options_CGOptions$method$verbose$e5b65d4727121643(_jc_env *, struct _jc_soot_options_CGOptions$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_options_CGOptions$method_info$all__5freachable$76af725e0b60b1e8;
extern _jc_method _jc_soot_options_CGOptions$method_info$context$b9f104a3d74cd388;
extern _jc_method _jc_soot_options_CGOptions$method_info$enabled$e29aaa88d18be18b;
extern _jc_method _jc_soot_options_CGOptions$method_info$safe__5fforname$2fffd7f4e2de688e;
extern _jc_method _jc_soot_options_CGOptions$method_info$safe__5fnewinstance$18b0fbec20bbaa49;
extern _jc_method _jc_soot_options_CGOptions$method_info$trim__5fclinit$5a845e4a8bc0b3d8;
extern _jc_method _jc_soot_options_CGOptions$method_info$verbose$e5b65d4727121643;

// Virtual methods structure
struct _jc_soot_options_CGOptions$vmethods {
	jboolean	(*all__5freachable$76af725e0b60b1e8)(_jc_env *, struct _jc_soot_options_CGOptions$object *);
	jint	(*context$b9f104a3d74cd388)(_jc_env *, struct _jc_soot_options_CGOptions$object *);
	jboolean	(*enabled$e29aaa88d18be18b)(_jc_env *, struct _jc_soot_options_CGOptions$object *);
	jboolean	(*safe__5fforname$2fffd7f4e2de688e)(_jc_env *, struct _jc_soot_options_CGOptions$object *);
	jboolean	(*safe__5fnewinstance$18b0fbec20bbaa49)(_jc_env *, struct _jc_soot_options_CGOptions$object *);
	jboolean	(*trim__5fclinit$5a845e4a8bc0b3d8)(_jc_env *, struct _jc_soot_options_CGOptions$object *);
	jboolean	(*verbose$e5b65d4727121643)(_jc_env *, struct _jc_soot_options_CGOptions$object *);
};

// Vtable
struct _jc_soot_options_CGOptions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_options_CGOptions$vmethods	soot_options_CGOptions;
};

// Vtype
struct _jc_soot_options_CGOptions$vtype {
	_jc_type			type;
	_jc_soot_options_CGOptions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_options_CGOptions$sub_refs {
	struct _jc_object	*options;
};

// Reference instance fields (object)
struct _jc_soot_options_CGOptions$refs {
    _jc_soot_options_CGOptions$sub_refs	soot_options_CGOptions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_options_CGOptions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_options_CGOptions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_options_CGOptions$sub_nonrefs	soot_options_CGOptions;
};

// Object instance structure
struct _jc_soot_options_CGOptions$object {
	_jc_soot_options_CGOptions$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_options_CGOptions$vtype	*vtype;
	_jc_soot_options_CGOptions$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_options_CGOptions$vtype _jc_soot_options_CGOptions$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_options_CGOptions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_options_CGOptions$class_object;

#endif	/* _JC_soot_options_CGOptions_H_ */

==> jc-1.4.6.tar.gz: soot/options/CGOptions.h <==
// public class soot.options.CGOptions

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 788d78022c32bf6e soot_options_CGOptions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_options_CGOptions_H_
#define _JC_soot_options_CGOptions_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_soot_options_CGOptions$sub_refs	_jc_soot_options_CGOptions$sub_refs;
typedef struct _jc_soot_options_CGOptions$sub_nonrefs	_jc_soot_options_CGOptions$sub_nonrefs;
typedef struct _jc_soot_options_CGOptions$refs	_jc_soot_options_CGOptions$refs;
typedef struct _jc_soot_options_CGOptions$nonrefs	_jc_soot_options_CGOptions$nonrefs;
typedef struct _jc_soot_options_CGOptions$object	_jc_soot_options_CGOptions$object;

typedef struct _jc_soot_options_CGOptions$fields_struct	_jc_soot_options_CGOptions$fields_struct;
typedef const struct _jc_soot_options_CGOptions$vmethods	_jc_soot_options_CGOptions$vmethods;
typedef const struct _jc_soot_options_CGOptions$vtable	_jc_soot_options_CGOptions$vtable;
typedef const struct _jc_soot_options_CGOptions$vtype	_jc_soot_options_CGOptions$vtype;

// Class fields structure
struct _jc_soot_options_CGOptions$fields_struct {
	jint	context__5f1cfa;
	jint	context__5finsens;
	jint	context__5fobjsens;
};
extern _jc_soot_options_CGOptions$fields_struct _jc_soot_options_CGOptions$class_fields;

// Constructors
extern void _jc_soot_options_CGOptions$method$_init$39bc1e191d75104e(_jc_env *, struct _jc_soot_options_CGOptions$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_options_CGOptions$method$all__5freachable$76af725e0b60b1e8(_jc_env *, struct _jc_soot_options_CGOptions$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_options_CGOptions$method$context$b9f104a3d74cd388(_jc_env *, struct _jc_soot_options_CGOptions$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_options_CGOptions$method$enabled$e29aaa88d18be18b(_jc_env *, struct _jc_soot_options_CGOptions$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_options_CGOptions$method$safe__5fforname$2fffd7f4e2de688e(_jc_env *, struct _jc_soot_options_CGOptions$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_options_CGOptions$method$safe__5fnewinstance$18b0fbec20bbaa49(_jc_env *, struct _jc_soot_options_CGOptions$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_options_CGOptions$method$trim__5fclinit$5a845e4a8bc0b3d8(_jc_env *, struct _jc_soot_options_CGOptions$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_options_CGOptions$method$verbose$e5b65d4727121643(_jc_env *, struct _jc_soot_options_CGOptions$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_options_CGOptions$method_info$all__5freachable$76af725e0b60b1e8;
extern _jc_method _jc_soot_options_CGOptions$method_info$context$b9f104a3d74cd388;
extern _jc_method _jc_soot_options_CGOptions$method_info$enabled$e29aaa88d18be18b;
extern _jc_method _jc_soot_options_CGOptions$method_info$safe__5fforname$2fffd7f4e2de688e;
extern _jc_method _jc_soot_options_CGOptions$method_info$safe__5fnewinstance$18b0fbec20bbaa49;
extern _jc_method _jc_soot_options_CGOptions$method_info$trim__5fclinit$5a845e4a8bc0b3d8;
extern _jc_method _jc_soot_options_CGOptions$method_info$verbose$e5b65d4727121643;

// Virtual methods structure
struct _jc_soot_options_CGOptions$vmethods {
	jboolean	(*all__5freachable$76af725e0b60b1e8)(_jc_env *, struct _jc_soot_options_CGOptions$object *) _JC_JCNI_ATTR;
	jint	(*context$b9f104a3d74cd388)(_jc_env *, struct _jc_soot_options_CGOptions$object *) _JC_JCNI_ATTR;
	jboolean	(*enabled$e29aaa88d18be18b)(_jc_env *, struct _jc_soot_options_CGOptions$object *) _JC_JCNI_ATTR;
	jboolean	(*safe__5fforname$2fffd7f4e2de688e)(_jc_env *, struct _jc_soot_options_CGOptions$object *) _JC_JCNI_ATTR;
	jboolean	(*safe__5fnewinstance$18b0fbec20bbaa49)(_jc_env *, struct _jc_soot_options_CGOptions$object *) _JC_JCNI_ATTR;
	jboolean	(*trim__5fclinit$5a845e4a8bc0b3d8)(_jc_env *, struct _jc_soot_options_CGOptions$object *) _JC_JCNI_ATTR;
	jboolean	(*verbose$e5b65d4727121643)(_jc_env *, struct _jc_soot_options_CGOptions$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_options_CGOptions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_options_CGOptions$vmethods	soot_options_CGOptions;
};

// Vtype
struct _jc_soot_options_CGOptions$vtype {
	_jc_type			type;
	_jc_soot_options_CGOptions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_options_CGOptions$sub_refs {
	struct _jc_object	*options;
};

// Reference instance fields (object)
struct _jc_soot_options_CGOptions$refs {
    _jc_soot_options_CGOptions$sub_refs	soot_options_CGOptions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_options_CGOptions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_options_CGOptions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_options_CGOptions$sub_nonrefs	soot_options_CGOptions;
};

// Object instance structure
struct _jc_soot_options_CGOptions$object {
	_jc_soot_options_CGOptions$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_options_CGOptions$vtype	*vtype;
	_jc_soot_options_CGOptions$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_options_CGOptions$vtype _jc_soot_options_CGOptions$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_options_CGOptions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_options_CGOptions$class_object;

#endif	/* _JC_soot_options_CGOptions_H_ */
